@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -29,6 +24,7 @@ $this->includeJsFile('configuration.host.edit.html.js.php');
 $host_is_discovered = ($data['host']['flags'] == ZBX_FLAG_DISCOVERY_CREATED);
 
 $host_form = (new CForm())
+	->addItem((new CVar(CSRF_TOKEN_NAME, CCsrfTokenHelper::get('host')))->removeId())
 	->setId($data['form_name'])
 	->setName($data['form_name'])
 	->setAction((new CUrl('zabbix.php'))
@@ -37,27 +33,30 @@ $host_form = (new CForm())
 	)
 	->addVar('hostid', $data['hostid'])
 	->addVar('clone_hostid', $data['clone_hostid'])
-	->addVar('full_clone', $data['full_clone'])
-	->addItem((new CInput('submit', null))->addStyle('display: none;'));
+	->addVar('clone', $data['clone'])
+	->addItem((new CSubmitButton())->addClass(ZBX_STYLE_FORM_SUBMIT_HIDDEN));
 
 // Host tab.
 $discovered_by = null;
 $interfaces_row = null;
 
 if ($host_is_discovered) {
-	if ($data['editable_discovery_rules']) {
-		$discovery_rule = (new CLink($data['host']['discoveryRule']['name'],
-			(new CUrl('host_prototypes.php'))
-				->setArgument('form', 'update')
-				->setArgument('parent_discoveryid', $data['host']['discoveryRule']['itemid'])
-				->setArgument('hostid', $data['host']['hostDiscovery']['parent_hostid'])
-				->setArgument('context', 'host')
-		))->setAttribute('target', '_blank');
+	if ($data['host']['discoveryRule']) {
+		if ($data['is_discovery_rule_editable']) {
+			$discovery_rule = (new CLink($data['host']['discoveryRule']['name'],
+				(new CUrl('host_prototypes.php'))
+					->setArgument('form', 'update')
+					->setArgument('parent_discoveryid', $data['host']['discoveryRule']['itemid'])
+					->setArgument('hostid', $data['host']['hostDiscovery']['parent_hostid'])
+					->setArgument('context', 'host')
+			))->setAttribute('target', '_blank');
+		}
+		else {
+			$discovery_rule = new CSpan($data['host']['discoveryRule']['name']);
+		}
 	}
 	else {
-		$discovery_rule = $data['host']['discoveryRule']
-			? (new CSpan($data['host']['discoveryRule']['name']))
-			: (new CSpan(_('Inaccessible discovery rule')))->addClass(ZBX_STYLE_GREY);
+		$discovery_rule = (new CSpan(_('Inaccessible discovery rule')))->addClass(ZBX_STYLE_GREY);
 	}
 
 	$discovered_by = [new CLabel(_('Discovered by')), new CFormField($discovery_rule)];
@@ -112,13 +111,11 @@ if ($data['host']['parentTemplates']) {
 		->addStyle('width: '.ZBX_TEXTAREA_STANDARD_WIDTH.'px;');
 
 	foreach ($data['host']['parentTemplates'] as $template) {
-		if ($data['allowed_ui_conf_templates']
+		if ($data['user']['can_edit_templates']
 				&& array_key_exists($template['templateid'], $data['editable_templates'])) {
-			$template_link = (new CLink($template['name'],
-				(new CUrl('templates.php'))
-					->setArgument('form','update')
-					->setArgument('templateid', $template['templateid'])
-			))->setTarget('_blank');
+			$template_link = (new CLink($template['name']))
+				->addClass('js-edit-linked-template')
+				->setAttribute('data-templateid', $template['templateid']);
 		}
 		else {
 			$template_link = new CSpan($template['name']);
@@ -140,14 +137,11 @@ if ($data['host']['parentTemplates']) {
 			(new CCol(
 				($template['link_type'] == TEMPLATE_LINK_MANUAL)
 					? new CHorList([
-						(new CSimpleButton(_('Unlink')))
-							->onClick('host_edit.unlinkTemplate(this)')
-							->addClass(ZBX_STYLE_BTN_LINK),
+						(new CButtonLink(_('Unlink')))->onClick('host_edit.unlinkTemplate(this)'),
 						($data['clone_hostid'] === null)
-							? (new CSimpleButton(_('Unlink and clear')))
+							? (new CButtonLink(_('Unlink and clear')))
 								->setAttribute('data-templateid', $template['templateid'])
 								->onClick('host_edit.unlinkAndClearTemplate(this, this.dataset.templateid)')
-								->addClass(ZBX_STYLE_BTN_LINK)
 							: null
 					])
 					: ''
@@ -176,6 +170,12 @@ $templates_field_items[] = (new CMultiSelect([
 	]
 ]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
+$disabled_by_lld_icon = $data['host']['status'] == HOST_STATUS_NOT_MONITORED
+		&& array_key_exists('hostDiscovery', $data['host']) && $data['host']['hostDiscovery']
+		&& $data['host']['hostDiscovery']['disable_source'] == ZBX_DISABLE_SOURCE_LLD
+	? makeWarningIcon(_('Disabled automatically by an LLD rule.'))
+	: null;
+
 $host_tab
 	->addItem([
 		new CLabel([
@@ -201,7 +201,7 @@ $host_tab
 			(new CMultiSelect([
 				'name' => 'groups[]',
 				'object_name' => 'hostGroup',
-				'disabled' => $host_is_discovered,
+				'readonly' => $host_is_discovered,
 				'add_new' => (CWebUser::$data['type'] == USER_TYPE_SUPER_ADMIN),
 				'data' => $data['groups_ms'],
 				'popup' => [
@@ -232,8 +232,8 @@ $host_tab
 			$host_is_discovered
 				? null
 				: new CDiv(
-					(new CButton(null, _('Add')))
-						->addClass(ZBX_STYLE_BTN_LINK)
+					(new CButtonLink(_('Add')))
+						->addClass('add-interface')
 						->setMenuPopup([
 							'type' => 'submenu',
 							'data' => [
@@ -253,54 +253,116 @@ $host_tab
 		)
 	])
 	->addItem([
-		new CLabel(_('Monitored by proxy'), 'label-proxy'),
+		new CLabel(_('Monitored by'), 'label-proxy'),
 		new CFormField(
-			(new CSelect('proxy_hostid'))
-				->setValue($data['host']['proxy_hostid'])
-				->setFocusableElementId('label-proxy')
+			(new CRadioButtonList('monitored_by', (int) $data['host']['monitored_by']))
+				->addValue(_('Server'), ZBX_MONITORED_BY_SERVER)
+				->addValue(_('Proxy'), ZBX_MONITORED_BY_PROXY)
+				->addValue(_('Proxy group'), ZBX_MONITORED_BY_PROXY_GROUP)
 				->setReadonly($host_is_discovered)
-				->addOptions(CSelect::createOptionsFromArray([0 => _('(no proxy)')] + $data['proxies']))
+				->setModern()
 		)
 	])
 	->addItem([
-		new CLabel(_('Enabled'), 'status'),
+		(new CFormField(
+			(new CMultiSelect([
+				'name' => 'proxyid',
+				'object_name' => 'proxies',
+				'multiple' => false,
+				'data' => $data['ms_proxy'],
+				'disabled' => $host_is_discovered,
+				'popup' => [
+					'parameters' => [
+						'srctbl' => 'proxies',
+						'srcfld1' => 'proxyid',
+						'srcfld2' => 'name',
+						'dstfrm' => $host_form->getName(),
+						'dstfld1' => 'proxyid'
+					]
+				]
+			]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		))->addClass('js-field-proxy')
+	])
+	->addItem([
+		(new CFormField(
+			(new CMultiSelect([
+				'name' => 'proxy_groupid',
+				'object_name' => 'proxy_groups',
+				'multiple' => false,
+				'data' => $data['ms_proxy_group'],
+				'disabled' => $host_is_discovered,
+				'popup' => [
+					'parameters' => [
+						'srctbl' => 'proxy_groups',
+						'srcfld1' => 'proxy_groupid',
+						'srcfld2' => 'name',
+						'dstfrm' => $host_form->getName(),
+						'dstfld1' => 'proxy_groupid'
+					]
+				]
+			]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
+		))->addClass('js-field-proxy-group')
+	])
+	->addItem([
+		new CLabel([_('Enabled'), $disabled_by_lld_icon], 'status'),
 		new CFormField(
 			(new CCheckBox('status', HOST_STATUS_MONITORED))
 				->setChecked($data['host']['status'] == HOST_STATUS_MONITORED)
 		)
 	]);
 
-// IPMI tab.
-if ($host_is_discovered) {
-	$ipmi_authtype_select = [
-		(new CTextBox('ipmi_authtype_name', ipmiAuthTypes($data['host']['ipmi_authtype']), true))
-			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH),
-		new CVar('ipmi_authtype', $data['host']['ipmi_authtype'])
-	];
-	$ipmi_privilege_select = [
-		(new CTextBox('ipmi_privilege_name', ipmiPrivileges($data['host']['ipmi_privilege']), true))
-			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH),
-		new CVar('ipmi_privilege', $data['host']['ipmi_privilege'])
-	];
-}
-else {
-	$ipmi_authtype_select = new CListBox('ipmi_authtype', $data['host']['ipmi_authtype'], 7, ipmiAuthTypes());
-	$ipmi_privilege_select = new CListBox('ipmi_privilege', $data['host']['ipmi_privilege'], 5, ipmiPrivileges());
+$proxy_name = null;
+
+if ($data['host']['assigned_proxyid'] != 0) {
+	$proxy_name = $data['user']['can_edit_proxies']
+		? (new CLink($data['host']['assigned_proxy_name']))
+			->addClass('js-edit-proxy')
+			->setAttribute('data-proxyid', $data['host']['assigned_proxyid'])
+		: new CSpan($data['host']['assigned_proxy_name']);
+	$proxy_name->addClass('js-proxy-assigned');
 }
 
+$host_tab->addItem([
+	(new CLabel(_('Assigned proxy')))->addClass('js-field-proxy-group-proxy'),
+	(new CFormField([
+		$proxy_name,
+		(new CSpan(_('Proxy is not assigned yet.')))
+			->addClass(ZBX_STYLE_GREY)
+			->addClass('js-proxy-not-assigned')
+	]))->addClass('js-field-proxy-group-proxy')
+]);
+
 $ipmi_tab = (new CFormGrid())
 	->addItem([
-		new CLabel(_('Authentication algorithm'), 'ipmi_authtype'),
-		new CFormField($ipmi_authtype_select)
+		new CLabel(_('Authentication algorithm'), 'label_ipmi_authtype'),
+		new CFormField(
+			(new CSelect('ipmi_authtype'))
+				->setValue($data['host']['ipmi_authtype'])
+				->setFocusableElementId('label_ipmi_authtype')
+				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+				->addOptions(CSelect::createOptionsFromArray(ipmiAuthTypes()))
+				->setReadonly($host_is_discovered)
+				->setId('ipmi_authtype')
+		)
 	])
 	->addItem([
-		new CLabel(_('Privilege level'), 'ipmi_privilege'),
-		new CFormField($ipmi_privilege_select)
+		new CLabel(_('Privilege level'), 'label_ipmi_privilege'),
+		new CFormField(
+			(new CSelect('ipmi_privilege'))
+				->setValue($data['host']['ipmi_privilege'])
+				->setFocusableElementId('label_ipmi_privilege')
+				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
+				->addOptions(CSelect::createOptionsFromArray(ipmiPrivileges()))
+				->setReadonly($host_is_discovered)
+				->setId('ipmi_privilege')
+		)
 	])
 	->addItem([
 		new CLabel(_('Username'), 'ipmi_username'),
 		new CFormField(
-			(new CTextBox('ipmi_username', $data['host']['ipmi_username'], $host_is_discovered))
+			(new CTextBox('ipmi_username', $data['host']['ipmi_username'], $host_is_discovered,
+				DB::getFieldLength('hosts', 'ipmi_username')
+			))
 				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 				->disableAutocomplete()
 		)
@@ -308,7 +370,9 @@ $ipmi_tab = (new CFormGrid())
 	->addItem([
 		new CLabel(_('Password'), 'ipmi_password'),
 		new CFormField(
-			(new CTextBox('ipmi_password', $data['host']['ipmi_password'], $host_is_discovered))
+			(new CTextBox('ipmi_password', $data['host']['ipmi_password'], $host_is_discovered,
+				DB::getFieldLength('hosts', 'ipmi_password')
+			))
 				->setWidth(ZBX_TEXTAREA_SMALL_WIDTH)
 				->disableAutocomplete()
 		)
@@ -319,8 +383,8 @@ $tags_tab = new CPartial('configuration.tags.tab', [
 	'source' => 'host',
 	'tags' => $data['host']['tags'],
 	'with_automatic' => true,
-	'readonly' => false,
-	'tabs_id' => 'host-tabs'
+	'tabs_id' => 'host-tabs',
+	'tags_tab_id' => 'host-tags-tab'
 ]);
 
 // Macros tab.
@@ -346,8 +410,8 @@ $inventory_tab = (new CFormGrid())
 				->addValue(_('Disabled'), HOST_INVENTORY_DISABLED)
 				->addValue(_('Manual'), HOST_INVENTORY_MANUAL)
 				->addValue(_('Automatic'), HOST_INVENTORY_AUTOMATIC)
-				->setEnabled(!$host_is_discovered)
-				->setModern(true),
+				->setReadonly($host_is_discovered)
+				->setModern(),
 			$host_is_discovered ? new CInput('hidden', 'inventory_mode', $data['host']['inventory_mode']) : null
 		])
 	]);
@@ -359,7 +423,7 @@ foreach ($data['inventory_fields'] as $inventory_no => $inventory_field) {
 		$data['host']['inventory'][$field_name] = '';
 	}
 
-	if ($inventory_field['type'] == DB::FIELD_TYPE_TEXT) {
+	if ($inventory_field['type'] & DB::FIELD_TYPE_TEXT) {
 		$input_field = (new CTextArea('host_inventory['.$field_name.']', $data['host']['inventory'][$field_name]))
 			->setWidth(ZBX_TEXTAREA_BIG_WIDTH);
 	}
@@ -377,15 +441,13 @@ foreach ($data['inventory_fields'] as $inventory_no => $inventory_field) {
 	if (array_key_exists($inventory_no, $data['inventory_items'])) {
 		$item_name = $data['inventory_items'][$inventory_no]['name'];
 
-		$link = (new CLink($item_name,
-			(new CUrl('items.php'))
-				->setArgument('form', 'update')
-				->setArgument('itemid', $data['inventory_items'][$inventory_no]['itemid'])
-				->setArgument('context', 'host')
-				->getUrl()
-		))->setTitle(_s('This field is automatically populated by item "%1$s".', $item_name));
+		$link = (new CLink($item_name))
+			->setTitle(_s('This field is automatically populated by item "%1$s".', $item_name))
+			->setAttribute('data-itemid', $data['inventory_items'][$inventory_no]['itemid'])
+			->setAttribute('data-context', 'host')
+			->addClass('js-update-item');
 
-		$inventory_item = (new CSpan([' &larr; ', $link]))->addClass('populating_item');
+		$inventory_item = (new CSpan([' ', LARR(), ' ', $link]))->addClass('populating_item');
 		$input_field->addClass('linked_to_item');
 
 		if ($data['host']['inventory_mode'] == HOST_INVENTORY_AUTOMATIC) {
@@ -420,7 +482,7 @@ $encryption_tab = (new CFormGrid())
 				->addValue(_('PSK'), HOST_ENCRYPTION_PSK)
 				->addValue(_('Certificate'), HOST_ENCRYPTION_CERTIFICATE)
 				->setModern(true)
-				->setEnabled(!$host_is_discovered)
+				->setReadonly($host_is_discovered)
 		)
 	])
 	->addItem([
@@ -430,15 +492,15 @@ $encryption_tab = (new CFormGrid())
 				(new CCheckBox('tls_in_none'))
 					->setChecked(($tls_accept & HOST_ENCRYPTION_NONE))
 					->setLabel(_('No encryption'))
-					->setEnabled(!$host_is_discovered),
+					->setReadonly($host_is_discovered),
 				(new CCheckBox('tls_in_psk'))
 					->setChecked(($tls_accept & HOST_ENCRYPTION_PSK))
 					->setLabel(_('PSK'))
-					->setEnabled(!$host_is_discovered),
+					->setReadonly($host_is_discovered),
 				(new CCheckBox('tls_in_cert'))
 					->setChecked(($tls_accept & HOST_ENCRYPTION_CERTIFICATE))
 					->setLabel(_('Certificate'))
-					->setEnabled(!$host_is_discovered)
+					->setReadonly($host_is_discovered)
 			]))
 				->addClass(ZBX_STYLE_LIST_CHECK_RADIO),
 			new CInput('hidden', 'tls_accept', $tls_accept)
@@ -495,22 +557,26 @@ $encryption_tab = (new CFormGrid())
 
 // Value mapping tab.
 if (!$host_is_discovered) {
-	$value_mapping_tab = (new CFormList('valuemap-formlist'))
-		->addRow(null, new CPartial('configuration.valuemap', [
+	$value_mapping_tab = (new CFormList('valuemap-formlist'))->addRow(
+		_('Value mapping'),
+		new CPartial('configuration.valuemap', [
 			'source' => 'host',
 			'valuemaps' => $data['host']['valuemaps'],
 			'readonly' => $host_is_discovered,
-			'form' => 'host'
-		]));
+			'form' => 'host',
+			'table_id' => 'valuemap-table',
+			'with_label' => true
+		])
+	);
 }
 
 // main output
 $tabs = (new CTabView(['id' => 'host-tabs']))
 	->setSelected(0)
 	->addTab('host-tab', _('Host'), $host_tab)
-	->addTab('ipmi-tab', _('IPMI'), $ipmi_tab)
-	->addTab('tags-tab', _('Tags'), $tags_tab, TAB_INDICATOR_TAGS)
-	->addTab('macros-tab', _('Macros'), $macros_tab, TAB_INDICATOR_MACROS)
+	->addTab('ipmi-tab', _('IPMI'), $ipmi_tab, TAB_INDICATOR_IPMI)
+	->addTab('host-tags-tab', _('Tags'), $tags_tab, TAB_INDICATOR_TAGS)
+	->addTab('macros-tab', _('Macros'), $macros_tab, TAB_INDICATOR_HOST_MACROS)
 	->addTab('inventory-tab', _('Inventory'), $inventory_tab, TAB_INDICATOR_INVENTORY)
 	->addTab('encryption-tab', _('Encryption'), $encryption_tab, TAB_INDICATOR_ENCRYPTION);
 
